==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Kunde"

, "State"
: "Fylke"

, "Role"
: "Rolle"

, "Source"
: "Kilde"

, "Start"
: "Start"

, "Scheduled end"
: "Avtalt slutt"

, "End"
: "Slutt"

, "Turnover"
: "Omsetning"

, "Probability"
: "Sannsynlighet"

, "Folder"
: "Mappe"

, "Updated by"
: "Oppdater av"

, "Updated Fields:"
: "Oppdaterte Felter:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "Merker"

, "Lead %s has been changed"
: "Mulighet %s har blitt endret"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: "Mulighets Data"

, "Leadstate"
: "Mulighets fylke"

, "Leadtype"
: "Mulighets type"

, "Leadsource"
: "Mulighets kilde"

, "End Scheduled"
: "Slutt Avatalt"

, "Contacts"
: "Kontakter"

, "Address"
: "Adresse"

, "Telephone"
: "Telefon"

, "Email"
: "E-post"

, "Tasks"
: "Oppgaver"

, "Due Date"
: "Ferdig Innen"

, "Priority"
: "Prioritet"

, "Products"
: "Produkter"

, "low"
: "lav"

, "normal"
: "normal"

, "high"
: "høy"

, "urgent"
: "viktig"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: "behandle delte muligheter mapper"

, "Create new shared lead folders"
: "Opprett ny delt mulighet mappe"

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Rolle"

, "Lead, Leads"
: [
  "Mulighet"
 ,"Muligheter"

]
, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: "Mulighets navn"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses Tid"

, "Created By"
: ""

, "Estimated end"
: "Forventet slutt"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Post"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Change type to Customer"
: "Endre type til Kunde"

, "Responsible"
: "Ansvarlig"

, "Change type to Responsible"
: "Endre type til Ansvarlig"

, "Change type to Partner"
: "Endre type til Partner"

, "Change contact type"
: "Endre kontakt type"

, "Search for Contacts to add ..."
: "Søk etter Kontaker å legge til ..."

, "Name"
: "Navn"

, "Data"
: "Data"

, "Cellphone"
: "Mobil"

, "Add new {0}"
: "Legg til ny {0}"

, "Unlink {0}"
: "Frakoble {0}"

, "Unlink selected {0}"
: "Frakoble valgte {0}"

, "Edit {0}"
: "Rediger {0}"

, "Edit selected {0}"
: "Rediger valgte {0}"

, "No Tasks to display"
: "Ingen Oppgaver å vise"

, "Summary"
: "Sammendrag"

, "Add a task..."
: "Legg til en oppgave..."

, "Percent"
: "Prosent"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "Forventet omsetning"

, "Description"
: "Beskrivelse"

, "Enter description"
: "Tast inn beskrivelse"

, "New Lead"
: ""

, "Product"
: "Produkt"

, "Price"
: "Pris"

, "Quantity"
: "Kvantum"

, "Search for Products to add ..."
: "Søk etter Produkter å legge til ..."

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "åpen"

, "contacted"
: "kontaktet"

, "waiting for feedback"
: "venter på tilbakemelding"

, "quote sent"
: "tilbud sendt"

, "accepted"
: "akkseptert"

, "lost"
: "tapt"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Forhandler"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: "Mulighet"

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: "Merker"

, "Lead name"
: "Mulighets navn"

, "Responsible"
: "Ansvarlig"

, "Partner"
: "Partner"

, "Customer"
: "Kunde"

, "Leadstate"
: "Mulighets fylke"

, "Leadtype"
: "Mulighets type"

, "Leadsource"
: "Mulighets kilde"

, "Probability"
: "Sannsynlighet"

, "Turnover"
: "Omsetning"

, "Estimated end"
: "Forventet slutt"

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Rolle"

, "Tasks"
: "Oppgaver"

, "No Tasks to display"
: "Ingen Oppgaver å vise"

, "Summary"
: "Sammendrag"

, "Add a task..."
: "Legg til en oppgave..."

, "Due Date"
: "Ferdig Innen"

, "Priority"
: "Prioritet"

, "Percent"
: "Prosent"

, "Status"
: "Status"

, "Organizer"
: ""

, "Add new {0}"
: "Legg til ny {0}"

, "Unlink {0}"
: "Frakoble {0}"

, "Unlink selected {0}"
: "Frakoble valgte {0}"

, "Edit {0}"
: "Rediger {0}"

, "Edit selected {0}"
: "Rediger valgte {0}"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  "Mulighet"
 ,"Muligheter"

]
, "Select Lead"
: ""

, "Role"
: "Rolle"

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Post"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Start"

, "Change type to Customer"
: "Endre type til Kunde"

, "Change type to Responsible"
: "Endre type til Ansvarlig"

, "Change type to Partner"
: "Endre type til Partner"

, "Change contact type"
: "Endre kontakt type"

, "Search for Contacts to add ..."
: "Søk etter Kontaker å legge til ..."

, "Name"
: "Navn"

, "Address"
: "Adresse"

, "Data"
: "Data"

, "Cellphone"
: "Mobil"

, "End"
: "Slutt"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "Produkter"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "Forventet omsetning"

, "Description"
: "Beskrivelse"

, "Enter description"
: "Tast inn beskrivelse"

, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses Tid"

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produkt"

, "Price"
: "Pris"

, "Quantity"
: "Kvantum"

, "Search for Products to add ..."
: "Søk etter Produkter å legge til ..."

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "åpen"

, "contacted"
: "kontaktet"

, "waiting for feedback"
: "venter på tilbakemelding"

, "quote sent"
: "tilbud sendt"

, "accepted"
: "akkseptert"

, "lost"
: "tapt"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Forhandler"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Fylke"

, "Source"
: "Kilde"

, "Scheduled end"
: "Avtalt slutt"

, "Folder"
: "Mappe"

, "Updated by"
: "Oppdater av"

, "Updated Fields:"
: "Oppdaterte Felter:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Mulighet %s har blitt endret"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: "Mulighets Data"

, "End Scheduled"
: "Slutt Avatalt"

, "Contacts"
: "Kontakter"

, "Telephone"
: "Telefon"

, "Email"
: "E-post"

, "low"
: "lav"

, "normal"
: "normal"

, "high"
: "høy"

, "urgent"
: "viktig"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "behandle delte muligheter mapper"

, "Create new shared lead folders"
: "Opprett ny delt mulighet mappe"

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: "Mulighet"

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
